@@ -2,15 +2,19 @@
     0x11EDC6F41) value.
 
     requires sse4.2 support. (-msse4.2) *)
-external int_crc : initial:int -> data:int -> int = "caml_int_crc" "caml_int_crc_untagged"
-[@@noalloc] [@@untagged] [@@builtin] [@@no_effects] [@@no_coeffects]
+external int_crc
+  :  initial:int
+  -> data:int
+  -> int
+  = "caml_sse42_int_untagged_crc_bytecode" "caml_sse42_int_untagged_crc"
+  [@@noalloc] [@@untagged] [@@builtin] [@@no_effects] [@@no_coeffects]
 
 external int64_crc
   :  initial:(int[@untagged])
   -> data:(int64[@unboxed])
   -> (int[@untagged])
-  = "caml_int64_crc" "caml_int64_crc_unboxed"
-[@@noalloc] [@@builtin] [@@no_effects] [@@no_coeffects]
+  = "caml_sse42_int64_crc_bytecode" "caml_sse42_int64_crc"
+  [@@noalloc] [@@builtin] [@@no_effects] [@@no_coeffects]
 
 let iterated_crc_exn ~initial ~iterations ~data =
   if iterations < 0
