@@ -91,130 +91,181 @@ let%expect_test "iround_half_to_even" =
     iround_half_to_even 4611686018427387392 = 4611686018427387392
     iround_half_to_even 9223372036854774784 = 9223372036854774784
     iround_half_to_even -inf = -9223372036854775808
-    iround_half_to_even nan = -9223372036854775808 |}]
-;;
-
-let%expect_test "min and max" =
-  let args =
-    [ 0., 1.
-    ; 1., 0.
-    ; Float.neg_infinity, Float.infinity
-    ; Float.infinity, Float.neg_infinity
-    ; -0., 0.
-    ; 0., -0.
-    ; Float.nan, 0.
-    ; 0., Float.nan
-    ]
-  in
-  List.iter args ~f:(fun (x, y) -> printf "min %.19g %.19g = %.19g\n" x y (I.min x y));
-  [%expect
-    {|
-    min 0 1 = 0
-    min 1 0 = 0
-    min -inf inf = -inf
-    min inf -inf = -inf
-    min -0 0 = 0
-    min 0 -0 = -0
-    min nan 0 = 0
-    min 0 nan = nan |}];
-  List.iter args ~f:(fun (x, y) -> printf "max %.19g %.19g = %.19g\n" x y (I.max x y));
-  [%expect
-    {|
-    max 0 1 = 1
-    max 1 0 = 1
-    max -inf inf = inf
-    max inf -inf = inf
-    max -0 0 = 0
-    max 0 -0 = -0
-    max nan 0 = 0
-    max 0 nan = nan |}]
+    iround_half_to_even nan = -9223372036854775808
+    |}]
 ;;
 
 let%expect_test "round" =
   List.iter args ~f:(fun x ->
     let base_res = Base.Float.round_nearest_half_to_even x in
     let res = I.round_half_to_even x in
-    printf "round even  %.19g = %.19g" x res;
+    printf "[Base] round even (current) %.19g = %.19g" x res;
     if same_bits res base_res then printf "\n" else printf " != %.19g in base\n" base_res);
   [%expect
     {|
-    round even  inf = inf
-    round even  -9223372036854775808 = -9223372036854775808
-    round even  -4611686018427387904 = -4611686018427387904
-    round even  -3.5 = -4
-    round even  -3.25 = -3
-    round even  -3 = -3
-    round even  -2.75 = -3
-    round even  -2.5 = -2
-    round even  -2.25 = -2
-    round even  -2 = -2
-    round even  -1.75 = -2
-    round even  -1.5 = -2
-    round even  -1.25 = -1
-    round even  -1 = -1
-    round even  -0.75 = -1
-    round even  -0.5 = -0 != 0 in base
-    round even  -0.25 = -0 != 0 in base
-    round even  -0 = -0
-    round even  0 = 0
-    round even  0.25 = 0
-    round even  0.5 = 0
-    round even  0.75 = 1
-    round even  1 = 1
-    round even  1.25 = 1
-    round even  1.5 = 2
-    round even  1.75 = 2
-    round even  2 = 2
-    round even  2.25 = 2
-    round even  2.5 = 2
-    round even  2.75 = 3
-    round even  3 = 3
-    round even  3.25 = 3
-    round even  3.5 = 4
-    round even  4611686018427387392 = 4611686018427387392
-    round even  9223372036854774784 = 9223372036854774784
-    round even  -inf = -inf
-    round even  nan = nan |}];
+    [Base] round even (current) inf = inf
+    [Base] round even (current) -9223372036854775808 = -9223372036854775808
+    [Base] round even (current) -4611686018427387904 = -4611686018427387904
+    [Base] round even (current) -3.5 = -4
+    [Base] round even (current) -3.25 = -3
+    [Base] round even (current) -3 = -3
+    [Base] round even (current) -2.75 = -3
+    [Base] round even (current) -2.5 = -2
+    [Base] round even (current) -2.25 = -2
+    [Base] round even (current) -2 = -2
+    [Base] round even (current) -1.75 = -2
+    [Base] round even (current) -1.5 = -2
+    [Base] round even (current) -1.25 = -1
+    [Base] round even (current) -1 = -1
+    [Base] round even (current) -0.75 = -1
+    [Base] round even (current) -0.5 = -0 != 0 in base
+    [Base] round even (current) -0.25 = -0 != 0 in base
+    [Base] round even (current) -0 = -0
+    [Base] round even (current) 0 = 0
+    [Base] round even (current) 0.25 = 0
+    [Base] round even (current) 0.5 = 0
+    [Base] round even (current) 0.75 = 1
+    [Base] round even (current) 1 = 1
+    [Base] round even (current) 1.25 = 1
+    [Base] round even (current) 1.5 = 2
+    [Base] round even (current) 1.75 = 2
+    [Base] round even (current) 2 = 2
+    [Base] round even (current) 2.25 = 2
+    [Base] round even (current) 2.5 = 2
+    [Base] round even (current) 2.75 = 3
+    [Base] round even (current) 3 = 3
+    [Base] round even (current) 3.25 = 3
+    [Base] round even (current) 3.5 = 4
+    [Base] round even (current) 4611686018427387392 = 4611686018427387392
+    [Base] round even (current) 9223372036854774784 = 9223372036854774784
+    [Base] round even (current) -inf = -inf
+    [Base] round even (current) nan = nan
+    |}];
+  List.iter args ~f:(fun x ->
+    printf "round even (current) %.19g = %.19g\n" x (I.round_half_to_even x));
+  [%expect
+    {|
+    round even (current) inf = inf
+    round even (current) -9223372036854775808 = -9223372036854775808
+    round even (current) -4611686018427387904 = -4611686018427387904
+    round even (current) -3.5 = -4
+    round even (current) -3.25 = -3
+    round even (current) -3 = -3
+    round even (current) -2.75 = -3
+    round even (current) -2.5 = -2
+    round even (current) -2.25 = -2
+    round even (current) -2 = -2
+    round even (current) -1.75 = -2
+    round even (current) -1.5 = -2
+    round even (current) -1.25 = -1
+    round even (current) -1 = -1
+    round even (current) -0.75 = -1
+    round even (current) -0.5 = -0
+    round even (current) -0.25 = -0
+    round even (current) -0 = -0
+    round even (current) 0 = 0
+    round even (current) 0.25 = 0
+    round even (current) 0.5 = 0
+    round even (current) 0.75 = 1
+    round even (current) 1 = 1
+    round even (current) 1.25 = 1
+    round even (current) 1.5 = 2
+    round even (current) 1.75 = 2
+    round even (current) 2 = 2
+    round even (current) 2.25 = 2
+    round even (current) 2.5 = 2
+    round even (current) 2.75 = 3
+    round even (current) 3 = 3
+    round even (current) 3.25 = 3
+    round even (current) 3.5 = 4
+    round even (current) 4611686018427387392 = 4611686018427387392
+    round even (current) 9223372036854774784 = 9223372036854774784
+    round even (current) -inf = -inf
+    round even (current) nan = nan
+    |}];
+  List.iter args ~f:(fun x ->
+    printf "round nearest %.19g = %.19g\n" x (I.round_nearest x));
+  [%expect
+    {|
+    round nearest inf = inf
+    round nearest -9223372036854775808 = -9223372036854775808
+    round nearest -4611686018427387904 = -4611686018427387904
+    round nearest -3.5 = -4
+    round nearest -3.25 = -3
+    round nearest -3 = -3
+    round nearest -2.75 = -3
+    round nearest -2.5 = -2
+    round nearest -2.25 = -2
+    round nearest -2 = -2
+    round nearest -1.75 = -2
+    round nearest -1.5 = -2
+    round nearest -1.25 = -1
+    round nearest -1 = -1
+    round nearest -0.75 = -1
+    round nearest -0.5 = -0
+    round nearest -0.25 = -0
+    round nearest -0 = -0
+    round nearest 0 = 0
+    round nearest 0.25 = 0
+    round nearest 0.5 = 0
+    round nearest 0.75 = 1
+    round nearest 1 = 1
+    round nearest 1.25 = 1
+    round nearest 1.5 = 2
+    round nearest 1.75 = 2
+    round nearest 2 = 2
+    round nearest 2.25 = 2
+    round nearest 2.5 = 2
+    round nearest 2.75 = 3
+    round nearest 3 = 3
+    round nearest 3.25 = 3
+    round nearest 3.5 = 4
+    round nearest 4611686018427387392 = 4611686018427387392
+    round nearest 9223372036854774784 = 9223372036854774784
+    round nearest -inf = -inf
+    round nearest nan = nan
+    |}];
   List.iter args ~f:(fun x -> printf "round up %.19g = %.19g\n" x (I.round_up x));
   [%expect
     {|
- round up inf = inf
- round up -9223372036854775808 = -9223372036854775808
- round up -4611686018427387904 = -4611686018427387904
- round up -3.5 = -3
- round up -3.25 = -3
- round up -3 = -3
- round up -2.75 = -2
- round up -2.5 = -2
- round up -2.25 = -2
- round up -2 = -2
- round up -1.75 = -1
- round up -1.5 = -1
- round up -1.25 = -1
- round up -1 = -1
- round up -0.75 = -0
- round up -0.5 = -0
- round up -0.25 = -0
- round up -0 = -0
- round up 0 = 0
- round up 0.25 = 1
- round up 0.5 = 1
- round up 0.75 = 1
- round up 1 = 1
- round up 1.25 = 2
- round up 1.5 = 2
- round up 1.75 = 2
- round up 2 = 2
- round up 2.25 = 3
- round up 2.5 = 3
- round up 2.75 = 3
- round up 3 = 3
- round up 3.25 = 4
- round up 3.5 = 4
- round up 4611686018427387392 = 4611686018427387392
- round up 9223372036854774784 = 9223372036854774784
- round up -inf = -inf
- round up nan = nan |}];
+    round up inf = inf
+    round up -9223372036854775808 = -9223372036854775808
+    round up -4611686018427387904 = -4611686018427387904
+    round up -3.5 = -3
+    round up -3.25 = -3
+    round up -3 = -3
+    round up -2.75 = -2
+    round up -2.5 = -2
+    round up -2.25 = -2
+    round up -2 = -2
+    round up -1.75 = -1
+    round up -1.5 = -1
+    round up -1.25 = -1
+    round up -1 = -1
+    round up -0.75 = -0
+    round up -0.5 = -0
+    round up -0.25 = -0
+    round up -0 = -0
+    round up 0 = 0
+    round up 0.25 = 1
+    round up 0.5 = 1
+    round up 0.75 = 1
+    round up 1 = 1
+    round up 1.25 = 2
+    round up 1.5 = 2
+    round up 1.75 = 2
+    round up 2 = 2
+    round up 2.25 = 3
+    round up 2.5 = 3
+    round up 2.75 = 3
+    round up 3 = 3
+    round up 3.25 = 4
+    round up 3.5 = 4
+    round up 4611686018427387392 = 4611686018427387392
+    round up 9223372036854774784 = 9223372036854774784
+    round up -inf = -inf
+    round up nan = nan
+    |}];
   List.iter args ~f:(fun x -> printf "round down %.19g = %.19g\n" x (I.round_down x));
   [%expect
     {|
@@ -254,7 +305,8 @@ let%expect_test "round" =
     round down 4611686018427387392 = 4611686018427387392
     round down 9223372036854774784 = 9223372036854774784
     round down -inf = -inf
-    round down nan = nan |}];
+    round down nan = nan
+    |}];
   List.iter args ~f:(fun x ->
     printf "round to zero %.19g = %.19g\n" x (I.round_towards_zero x));
   [%expect
@@ -295,7 +347,8 @@ let%expect_test "round" =
     round to zero 4611686018427387392 = 4611686018427387392
     round to zero 9223372036854774784 = 9223372036854774784
     round to zero -inf = -inf
-    round to zero nan = nan |}]
+    round to zero nan = nan
+    |}]
 ;;
 
 [%%ifdef JSC_ARCH_SIXTYFOUR]
@@ -344,7 +397,8 @@ let%expect_test "bit_of_float" =
     bits_of_float 4611686018427387392 = 4886405595696988159 -> 4611686018427387392
     bits_of_float 9223372036854774784 = 4890909195324358655 -> 9223372036854774784
     bits_of_float -inf = -4503599627370496 -> -inf
-    bits_of_float nan = 9221120237041090561 -> nan |}]
+    bits_of_float nan = 9221120237041090561 -> nan
+    |}]
 ;;
 
 [%%else]
@@ -394,7 +448,8 @@ let%expect_test "bit_of_float" =
     bits_of_float 3.5 = 4615063718147915776 -> 3.5
     bits_of_float 4611686018427387392 = 4886405595696988159 -> 4611686018427387392
     bits_of_float 9223372036854774784 = 4890909195324358655 -> 9223372036854774784
-    bits_of_float -inf = -4503599627370496 -> -inf |}]
+    bits_of_float -inf = -4503599627370496 -> -inf
+    |}]
 ;;
 
 [%%endif]
